I hate money
############

.. image:: https://travis-ci.org/spiral-project/ihatemoney.svg?branch=master
   :target: https://travis-ci.org/spiral-project/ihatemoney
   :alt: Travis CI Build Status

«I hate money» is a web application made to ease shared budget management.
It keeps track of who bought what, when, and for whom; and helps to settle the
bills.

* `Online documentation <https://ihatemoney.readthedocs.org>`_
* `Hosted version <https://ihatemoney.org>`_

The code is distributed under a BSD *beerware* derivative: if you meet the people
in person and you want to pay them a craft beer, you are highly encouraged to do
so.

Requirements
============

* **Python**: 2.7, 3.4, 3.5, 3.6.
* **Backends**: MySQL, PostgreSQL, SQLite, Memory.
